@@ -28,6 +28,7 @@ import Data.Monoid
 import qualified System.Process as P
 import qualified Data.Text as T
 import qualified Data.Text.IO as T
+import qualified Data.Text.Lazy as L
 import Control.Applicative
 import Prelude
 
@@ -136,6 +137,11 @@ class Outputable v where
 instance Outputable T.Text where
 	toOutput = id
 
+-- | Note that using a lazy Text as an Outputable value 
+-- will buffer it all in memory.
+instance Outputable L.Text where
+	toOutput = toOutput . L.toStrict
+
 instance Outputable String where
 	toOutput = toOutput . T.pack
 
