@@ -114,6 +114,7 @@ import Data.Monoid
 import Data.String
 import Data.Char
 import qualified Data.Text as T
+import qualified Data.Text.Lazy as L
 import qualified Data.Text.IO as T
 import Data.Text (Text)
 import Control.Monad
@@ -233,6 +234,10 @@ instance ToRegionContent String where
 instance ToRegionContent Text where
 	toRegionContent = fromOutput
 
+-- | Note that using a lazy Text in a region will buffer it all in memory.
+instance ToRegionContent L.Text where
+	toRegionContent = fromOutput
+
 fromOutput :: Outputable v => v -> RegionContent
 fromOutput = RegionContent . pure . toOutput
 
@@ -287,7 +292,7 @@ resizeRegion width (ConsoleRegion tv) = do
 
 -- | Runs the action with a new console region, closing the region when
 -- the action finishes or on exception.
-withConsoleRegion :: (LiftRegion m, MonadIO m, MonadMask m) => RegionLayout -> (ConsoleRegion -> m a) -> m a
+withConsoleRegion :: (MonadIO m, MonadMask m) => RegionLayout -> (ConsoleRegion -> m a) -> m a
 withConsoleRegion ly = bracketIO (openConsoleRegion ly) (closeConsoleRegion)
 
 -- | Opens a new console region.
